# Optimal production mix problem

# DATA
param P;						# Number of products
set Products := 1..P;			# Set of products
param R; 						# Number od resources
set Resources := 1..R;			# Set of resources
param c {Products};				# Unit profit for each type of product
param b {Resources};			# Amount of available resources
param a {Resources,Products};	# Technological coefficients

# VARIABLES
var x {Products} >=0;			# Production for each type of product

# CONSTRAINTS
# Constraint on the maximum allowed consumption of each resource
subject to Resource_consumption {i in Resources}:
  sum {j in Products} a[i,j] * x[j] <= b[i];
  
# OBJECTIVE
# Maximize the expected profit
maximize z: sum {j in Products} c[j] * x[j];

##########################
data;
param P := 3;
param R := 5;

param c :=
1	 840
2	1120
3	1200;

param b :=
1		120
2		 80
3		 96
4		102
5		 40;

param a:	1	2	3 :=
1			3	2	1
2			1	2	3
3			2	0	0
4			0	3	0
5			0	0	2;

end;
