# Multi-period single-product planning

# DATA
param T;				# Number of periods
set Periods := 1..T;	# Set of periods
param d {Periods};		# Demand for each period [units]
param prod_cap;			# Production capacity (monthly) [units/month]
param c;				# Unit production cost [/unit]
param extra_prod_cap;	# Extra production capacity (monthly) [units/month]
param extra_c;			# Unit cost of extra production [/unit]
param h;				# Unit inventory cost [/unit*month]
param s0;				# Initial stock level [units]
param lot_size;			# Number of units of product in a lot [units/lot]

# VARIABLES
var x {Periods} >=0, <= prod_cap/lot_size, integer;				# Normal production in each period [lots]
var extra_x {Periods} >=0, <= extra_prod_cap/lot_size, integer;	# Extra production in each period [lots]
var s {Periods} >=0;											# Stock at the end of each period [units]

# CONSTRAINTS
# Flow conservation [units]
subject to Flow_conservation {t in Periods: t>1}:
  s[t-1] + (x[t] + extra_x[t])*lot_size = d[t] + s[t];
subject to Flow_conservation1:
  s0 + (x[1] + extra_x[1])*lot_size = d[1] + s[1];

# OBJECTIVE
# Minimize total cost: production + extra production + inventory
minimize z: sum {t in Periods} (c*x[t]*lot_size + extra_c*extra_x[t]*lot_size + h*s[t]);

#######################
data;

param T := 3;

param prod_cap 			:= 110;	# units/month
param c 				:= 300;	# /unit
param extra_prod_cap	:= 60;	# units/month
param extra_c 			:= 330;	# /unit
param h 				:= 10;	# /unit*month
param s0 				:= 0;	# units
param lot_size			:= 5;	# units

param d :=
1	100
2	130
3	150;

end;
