# Exercise Lot sizing

# DATA
param T;					# Number of periods
set Periods := 1..T;		# Set of periods
param prod_cap {Periods};	# Production capacity [units]
param c {Periods};			# Unit cost for production [/unit]
param h {Periods};			# Unit inventory cost [/unit]
param f {Periods};			# Fixed cost for using a production period []
param d {Periods};			# Demand in each period [units]
param Q;					# Warehouse capacity [units]
param s0;					# Initial inventory [units]

# VARIABLES
var x {t in Periods} >=0;		# Production [units]
var s {Periods} >=0, <=Q;		# Inventory [units]
var y {Periods} binary;			# Use of each production period

# CONSTRAINTS
# Flow conservation constraints [units]
subject to Flow_conservation {t in Periods: t>1}:
  s[t-1] + x[t] = d[t] + s[t];
subject to Flow_conservation1:
  s0 + x[1] = d[1] + s[1];

# Link between x and y [units]
subject to Link {t in Periods}:
  x[t] <= prod_cap[t] * y[t];

# OBJECTIVE
# minimize the total cost: fixed + production + inventory
minimize z: sum {t in Periods} (f[t]*y[t] + c[t]*x[t] + h[t]*s[t]);

#################
data;
param T := 3;
param: prod_cap		c		h		f		d :=
1		320			300		10		10000	100
2		300			320		15		10000	130
3		340			350		10		15000	150;
param Q := 150;
param s0 := 0;

end;
