# Exercise Single-machine scheduling

# DATA
param N;			# Number of jobs
set Jobs := 1..N;	# Set of jobs
param p {Jobs};		# Processing time of each job
param r {Jobs};		# Release date of each job
param d {Jobs};		# Due date for each job
param M := sum {j in Jobs} p[j];

# VARIABLES
var x {Jobs,Jobs} binary;	# Precedence
var makespan;				# Makespan of the schedule
var T {Jobs} >=0;			# Tardiness of each job
var U {Jobs} binary;		# Tardy jobs
var max_lateness;
var t {i in Jobs} >=r[i];	# Starting time for each job

# CONSTRAINTS
# No overlap
subject to No_overlap {i in Jobs, j in Jobs: not(i=j)}:
  t[i] >= t[j] + p[j] - M * x[i,j];
subject to Disjunctions {i in Jobs, j in Jobs: i<>j}:
  x[i,j] + x[j,i] = 1;

# Due date constraints
subject to Due_dates {i in Jobs}:
  t[i] + p[i] <= d[i] + T[i];

# Link U with L
subject to Link_U_L {i in Jobs}:
  T[i] <= (sum {j in Jobs} p[j]-d[i]) * U[i];

# OBJECTIVE
# Minimize the makespan
minimize z1: makespan;
subject to min_max {i in Jobs}:
  makespan >= p[i] + sum {j in Jobs} p[j] * x[j,i];
# Minimize the average completion time
#minimize z2: sum {i in Jobs} (p[i] + sum {j in Jobs} p[j] * x[j,i]);
# Minimize the max lateness
#minimize z3: max_lateness;
#subject to min_max_late {i in Jobs}:
#  max_lateness >= T[i];
# Minimize the number of late jobs
#minimize z4: sum {i in Jobs} U[i];

#####################
data;
param N := 10;

param: 	p		r		d :=
1		10		15		50
2		14		0		80
3		21		0		95
4		18		10		75
5		4		5		30
6		23		13		130
7		35		18		120
8		5		5		150
9		19		5		140
10		13		12		160;

end;
